@@ -84,7 +84,7 @@ class OutgoingMessageViewSet(mixins.ListModelMixin,
     """
     A ViewSet for viewing outgoing message.
     """
-    queryset = OutgoingMessage.objects.select_related('user', 'notification_event').all()
+    queryset = OutgoingMessage.objects.all()
     serializer_class = OutgoingMessageSerializer
     authentication_classes = [JWTAuthentication]
     permission_classes = [IsAuthenticated, CustomDjangoModelPermissions]
@@ -95,6 +95,8 @@ class OutgoingMessageViewSet(mixins.ListModelMixin,
 
     def get_queryset(self):
         queryset = super().get_queryset()
+        queryset = queryset.prefetch_related('notification_event__attachments')
+        queryset = queryset.select_related('user', 'notification_event', 'notification_event__template')
         return queryset.filter(Q(user=self.request.user) | Q(recipient=self.request.user.email)).distinct()
 
 
