@@ -94,9 +94,8 @@ class NotificationEvent(BaseModel):
                                       related_name='notification_events')
     owner = models.ForeignKey(to=User, verbose_name=_('owner'), related_name='notification_events',
                               on_delete=models.PROTECT)
-    notification_group = models.ForeignKey(to=NotificationGroup, verbose_name=_('notification group'),
-                                           on_delete=models.PROTECT, related_name='notification_events',
-                                           null=True, blank=True)
+    notification_groups = models.ManyToManyField(to=NotificationGroup, verbose_name=_('notification groups'),
+                                                 blank=True, related_name='notification_events')
     template = models.ForeignKey(to=EmailTemplate, on_delete=models.PROTECT, related_name='notification_events',
                                  null=True, blank=True,
                                  help_text=_("If template is selected, HTML message and subject fields will not be used"
@@ -120,8 +119,9 @@ class NotificationEvent(BaseModel):
 
     def get_recipients(self):
         recipients = self.recipients.all()
-        if self.notification_group:
-            recipients = recipients | self.notification_group.members.all()
+
+        for notification_group in self.notification_groups.filter(is_active=True):
+            recipients = recipients | notification_group.members.all()
 
         return recipients.filter(is_active=True, email__isnull=False).distinct()
 
